@@ -306,3 +306,8 @@ register(options.Option('vm.uploaded_scripts.guest_dir',
                         default='~ubuntu/bin',
                         help_string='''\
 Where {vm.uploaded_scripts} are uploaded on the guest.'''))
+register(options.Option('vm.final_message',
+                        default=None,
+                        help_string='''\
+The cloud-init final message, a release-specific message is used if
+none is provided to address compatibility with Ubuntu precise.'''))
