@@ -284,6 +284,12 @@ class TestCIUserData(unittest.TestCase):
         self.assertEqual('uci-vms finished installing in $UPTIME seconds.',
                          self.ci_data.cloud_config['final_message'])
 
+    def test_final_message_explicit(self):
+        self.conf.store._load_from_string('vm.final_message = hello there')
+        self.ci_data.populate()
+        self.assertEqual('hello there',
+                         self.ci_data.cloud_config['final_message'])
+
     def test_poweroff_precise(self):
         self.conf.store._load_from_string('vm.release = precise')
         self.ci_data.populate()
@@ -415,15 +421,15 @@ user=root
         # The additional newline after the script is expected
         self.assertEqual('''\
 #!/bin/sh
-cat >~root/uci-vms_post_install <<'EOSETUPVMUNIQUECONTENTDONTBREAKFORFUN'
+cat >/tmp/root-uci-vms_post_install <<'EOSETUPVMUNIQUECONTENTDONTBREAKFORFUN'
 #!/bin/sh
 echo Hello root
 
 EOSETUPVMUNIQUECONTENTDONTBREAKFORFUN
-chown root:root ~root/uci-vms_post_install
-chmod 0700 ~root/uci-vms_post_install
+chown root:root /tmp/root-uci-vms_post_install
+chmod 0700 /tmp/root-uci-vms_post_install
 ''', self.ci_data.root_hook)
-        self.assertEqual(['~root/uci-vms_post_install'],
+        self.assertEqual(['/tmp/root-uci-vms_post_install'],
                          self.ci_data.cloud_config['runcmd'])
 
     def test_ubuntu_script(self):
@@ -439,17 +445,17 @@ user = ubuntu
         # The additional newline after the script is expected
         self.assertEqual('''\
 #!/bin/sh
-cat >~ubuntu/uci-vms_post_install <<'EOSETUPVMUNIQUECONTENTDONTBREAKFORFUN'
+cat >/tmp/ubuntu-uci-vms_post_install <<'EOSETUPVMUNIQUECONTENTDONTBREAKFORFUN'
 #!/bin/sh
 echo Hello ubuntu
 
 EOSETUPVMUNIQUECONTENTDONTBREAKFORFUN
-chown ubuntu:ubuntu ~ubuntu/uci-vms_post_install
-chmod 0700 ~ubuntu/uci-vms_post_install
+chown ubuntu:ubuntu /tmp/ubuntu-uci-vms_post_install
+chmod 0700 /tmp/ubuntu-uci-vms_post_install
 ''', self.ci_data.ubuntu_hook)
         # The command is run as root, so we need to 'su ubuntu' first
         self.assertEqual([['su', '-l',
-                          '-c', '~ubuntu/uci-vms_post_install',
+                          '-c', '/tmp/ubuntu-uci-vms_post_install',
                           'ubuntu']],
                          self.ci_data.cloud_config['runcmd'])
 
