@@ -149,7 +149,7 @@ class CIUserData(object):
         self.cloud_config['runcmd'] = cmds
 
     def _hook_script_path(self, user):
-        return '~%s/uci-vms_post_install' % (user,)
+        return '/tmp/{}-uci-vms_post_install'.format(user)
 
     def _hook_content(self, option_name, user, hook_path, mode='0700'):
         # FIXME: Add more tests towards properly creating a tree on the guest
@@ -301,11 +301,13 @@ chmod 0700 {hook_path}
         self.set('manage_etc_hosts', None, True)
         self.set('chpasswd', None, dict(expire=False))
         # Configurable options
-        if self.conf.get('vm.release') == 'precise':
-            # Curse cloud-init lack of compatibility
-            msg = 'uci-vms finished installing in $UPTIME seconds.'
-        else:
-            msg = 'uci-vms finished installing in ${uptime} seconds.'
+        msg = self.conf.get('vm.final_message')
+        if msg is None:
+            if self.conf.get('vm.release') == 'precise':
+                # Curse cloud-init lack of compatibility
+                msg = 'uci-vms finished installing in $UPTIME seconds.'
+            else:
+                msg = 'uci-vms finished installing in ${uptime} seconds.'
         self.set('final_message', None, msg)
         self.set('password', 'vm.password')
         self.set_list_of_paths('ssh_authorized_keys', 'vm.ssh_authorized_keys')
